#
# steering, Programme/schedule management for AURA
#
# Copyright (C) 2011-2017, 2020, Ernesto Rico Schmidt
# Copyright (C) 2017-2019, Ingo Leindecker
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from drf_spectacular.views import SpectacularAPIView, SpectacularSwaggerView
from rest_framework import routers

from django.conf import settings
from django.conf.urls.static import static
from django.contrib import admin
from django.urls import include, path
from program.views import (
    APICategoryViewSet,
    APIFundingCategoryViewSet,
    APIHostViewSet,
    APIImageViewSet,
    APILanguageViewSet,
    APILicenseViewSet,
    APILinkTypeViewSet,
    APIMusicFocusViewSet,
    APINoteViewSet,
    APIRadioSettingsViewSet,
    APIRRuleViewSet,
    APIScheduleViewSet,
    APIShowViewSet,
    APITimeSlotViewSet,
    APITopicViewSet,
    APITypeViewSet,
    APIUserViewSet,
    APIDayScheduleViewSet,
    APIPlayoutViewSet
)

admin.autodiscover()

router = routers.DefaultRouter()
router.register(r"users", APIUserViewSet, basename="user")
router.register(r"hosts", APIHostViewSet, basename="host")
router.register(r"shows", APIShowViewSet, basename="show")
router.register(r"schedules", APIScheduleViewSet, basename="schedule")
router.register(r"timeslots", APITimeSlotViewSet, basename="timeslot")
router.register(r"notes", APINoteViewSet, basename="note")
router.register(r"categories", APICategoryViewSet, basename="category")
router.register(r"topics", APITopicViewSet, basename="topic")
router.register(r"types", APITypeViewSet, basename="type")
router.register(r"music-focus", APIMusicFocusViewSet, basename="music-focus")
router.register(r"funding-categories", APIFundingCategoryViewSet, basename="funding-category")
router.register(r"languages", APILanguageViewSet, basename="language")
router.register(r"licenses", APILicenseViewSet, basename="license")
router.register(r"link-types", APILinkTypeViewSet, basename="link-type")
router.register(r"rrules", APIRRuleViewSet, basename="rrule")
router.register(r"images", APIImageViewSet, basename="image")
router.register(r"settings", APIRadioSettingsViewSet, basename="settings")
router.register(r"playout", APIPlayoutViewSet, basename="playout")
router.register(r"program/week", APIPlayoutViewSet, basename="program/week")
# router.register(r"program/<int:year>/<int:month>/<int:day>", APIDayScheduleViewSet, basename="program")

urlpatterns = [
    path("openid/", include("oidc_provider.urls", namespace="oidc_provider")),
    path("api/v1/", include(router.urls)),
    path("api/v1/program/<int:year>/<int:month>/<int:day>/", APIDayScheduleViewSet.as_view({'get': 'list'}), name="program"),
    path("api/v1/schema/", SpectacularAPIView.as_view(), name="schema"),
    path(
        "api/v1/schema/swagger-ui/",
        SpectacularSwaggerView.as_view(url_name="schema"),
        name="swagger-ui",
    ),
    path("admin/", admin.site.urls),
] + static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)
